<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>AdvancedConfigDialog</name>
    <message>
        <source>Advanced Settings</source>
        <translation>Дополнительные настройки</translation>
    </message>
    <message>
        <source>Crop Image When Loaded</source>
        <translation>Обрезать изображение при загрузке</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>OCR Settings</source>
        <translation>Настройки программ распознавания</translation>
    </message>
    <message>
        <source>OCR Engine</source>
        <translation>Программа распознавания</translation>
    </message>
    <message>
        <source>cuneiform</source>
        <translation>cuneiform</translation>
    </message>
    <message>
        <source>tesseract</source>
        <translation>tesseract</translation>
    </message>
    <message>
        <source>Tesseract Setup</source>
        <translation>Настройка tesseract</translation>
    </message>
    <message>
        <source>Location of the  tessdata directory:</source>
        <translation>Расположение директории tessdata:</translation>
    </message>
</context>
<context>
    <name>MainForm</name>
    <message>
        <source>Recognition language</source>
        <translation>Язык распознавания</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.jpeg *.bmp *.tiff *.tif *.gif *.pnm *.pgm *.pbm *.ppm)</source>
        <translation>Графические файлы  (*.png *.jpg *.jpeg *.bmp *.tiff *.tif *.gif *.pnm *.pgm *.pbm *.ppm)</translation>
    </message>
    <message>
        <source>There is an unsaved text in the editor window. Do you want to save it?</source>
        <translation>В окне редактора несохраненный текст. Сохранить?</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>No image loaded</source>
        <translation>Изображение не загружено</translation>
    </message>
    <message>
        <source>Starting cuneiform failed</source>
        <translation>Не удалось запустить cuneiform</translation>
    </message>
    <message>
        <source>The system said: </source>
        <translation>Ответ системы:</translation>
    </message>
    <message>
        <source>program not found</source>
        <translation>программа не найдена</translation>
    </message>
    <message>
        <source>About YAGF</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>http://symmetrica.net/cuneiform-linux/yagf-en.html</source>
        <translation>http://symmetrica.net/cuneiform-linux/yagf-ru.html</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>Recognizing pages...</source>
        <translation>Распознаем страницы...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Прервать</translation>
    </message>
    <message>
        <source>Importing pages from the PDF document...</source>
        <translation>Импорт страниц из документа PDF...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>No compatible PDF converter software could be found. Please install either the pdftoppm utility or the GhostScript package (from this the gs command will be required).</source>
        <translation>Не найдены подходящие конверторы PDF. Установите, пожалуйста, утилиту pdftoppm или пакет GhostScript (из которого требуется программа gs).</translation>
    </message>
    <message>
        <source>PDF file name may not be empty</source>
        <translation>Необходимо указать имя файла PDF</translation>
    </message>
    <message>
        <source>Select an existing directory for output or create some new one</source>
        <translation>Выберите существующую директорию для вывода или создайте новую</translation>
    </message>
    <message>
        <source>Selecting Directory</source>
        <translation>Выбор директории</translation>
    </message>
    <message>
        <source>The selected directory is not empty</source>
        <translation>Выбранная директория - не пустая</translation>
    </message>
    <message>
        <source>Starting tesseract failed</source>
        <translation>Не удалось запустить tesseract</translation>
    </message>
    <message>
        <source>cuneiform not found, switching to tesseract</source>
        <translation>Программа cuneiform не найдена, переключаемся на tesseract</translation>
    </message>
    <message>
        <source>No recognition engine found.
Please install either cuneiform or tesseract</source>
        <translation>Программа распознавания не найдена.
Установите, пожалуйста, cuneiform или tesseract</translation>
    </message>
    <message>
        <source>tesseract not found, switching to cuneiform</source>
        <translation>Программа tesseract не найдена, переключаемся на cuneiform</translation>
    </message>
    <message>
        <source>No PDF converter installed</source>
        <translation>Конвертер PDF не установлен</translation>
    </message>
    <message utf8="true">
        <source>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Version %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2012 Andrei Borovsky&lt;/p&gt; This is a free software distributed under GPL v3. Visit &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-en.html&lt;/a&gt; for more details.</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Графическая оболочка для программ распознавания текста cuneiform и tesseract&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Версия %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2012 Андрей Боровский&lt;/p&gt; YAGF - открытое программное обеспечение, которое распространяется на условиях лицензии GPL v3. Вы найдете подробности на странице &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-ru.html&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Using Cuneiform</source>
        <translation>Используется Cuneiform</translation>
    </message>
    <message>
        <source>Using Tesseract</source>
        <translation>Используется Tesseract</translation>
    </message>
    <message>
        <source>Scanning is impossible</source>
        <translation>Сканирование невозможно</translation>
    </message>
    <message>
        <source>No scanning front-end is found. Please install XSane in order to perform scanning.</source>
        <translation>Программа сканирования не найдена. Необходимо установить XSane.</translation>
    </message>
    <message>
        <source>Failed to Load Image</source>
        <translation>Невозможно загруить выбранное изобажение</translation>
    </message>
    <message>
        <source>Failed to detect text areas on this page.
The page possibly lacks contrast. Try to select blocks manually.</source>
        <translation>Не удалось найти ткстовые области на странице. Возможно, изображение отсканировано со слишком низким контрастом. Попробуйт выделить блоки вручную.</translation>
    </message>
    <message>
        <source>The selected directoy is not empty. Please select or create another one.</source>
        <translation>Выбранный каталог содержит файлы. Выберите пустой каталог или создайте новый.</translation>
    </message>
    <message>
        <source>Failed to save the project.</source>
        <translation>Ошибка при сохранении проекта.</translation>
    </message>
    <message>
        <source>Failed to load project.</source>
        <translation>Невозможно открыть проект.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>S&amp;can...</source>
        <translation>С&amp;канировать...</translation>
    </message>
    <message>
        <source>Scanning images using XSane...</source>
        <translation>Сканируем страницу с помощью XSane...</translation>
    </message>
    <message>
        <source>&amp;Save text...</source>
        <translation>&amp;Сохранить текст...</translation>
    </message>
    <message>
        <source>&amp;Open Image...</source>
        <translation>&amp;Открыть графический файл...</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Открыть графический файл</translation>
    </message>
    <message>
        <source>&amp;Recognize</source>
        <translation>&amp;Распознать</translation>
    </message>
    <message>
        <source>Recognizing text...</source>
        <translation>Распознать текст...</translation>
    </message>
    <message>
        <source>Choose &amp;Language</source>
        <translation>&amp;Выбрать язык</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Предыдущее изображение</translation>
    </message>
    <message>
        <source>Move to previous image</source>
        <translation>Перейти к предыдущему изображению</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Следующее изображение</translation>
    </message>
    <message>
        <source>Move to next image</source>
        <translation>Перейти к следующему изображению</translation>
    </message>
    <message>
        <source>Online Help</source>
        <translation>Справка онлайн</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>О програме...</translation>
    </message>
    <message>
        <source>Clear all blocks</source>
        <translation>Очистить все блоки</translation>
    </message>
    <message>
        <source>Delete the current block</source>
        <translation>Удалить этот блок</translation>
    </message>
    <message>
        <source>Recognize block</source>
        <translation>Распознать блок</translation>
    </message>
    <message>
        <source>Recognize this block</source>
        <translation>Распознать этот блок</translation>
    </message>
    <message>
        <source>Clear numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crear block numbering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check spelling</source>
        <translation>Проверить орфографию</translation>
    </message>
    <message>
        <source>Save current image...</source>
        <translation>Сохранить изображение...</translation>
    </message>
    <message>
        <source>Save currently opened image in its real size</source>
        <translation>Сохраняет полученное изображение в реальном размере</translation>
    </message>
    <message>
        <source>Save block</source>
        <translation>Сохранить блок</translation>
    </message>
    <message>
        <source>Save the current block to the image file</source>
        <translation>Сохранить этот блок в графическом файле</translation>
    </message>
    <message>
        <source>Select HTML format</source>
        <translation>Выбрать формат HTML</translation>
    </message>
    <message>
        <source>Select HTML format as recognition output</source>
        <translation>Выбрать HTML в качестве формата вывода распознанного текста</translation>
    </message>
    <message>
        <source>Larger view</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <source>Smaller view</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <source>Rotate 90 CCW</source>
        <translation>Повернуть на 90 градусов против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate 180</source>
        <translation>Повернуть на 180 градусов</translation>
    </message>
    <message>
        <source>Rotate 90 CW</source>
        <translation>Повернуть на 90 градусов по часовой стрелке</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>Copy To Clipboard</source>
        <translation>Копировать текст в буфер обмена</translation>
    </message>
    <message>
        <source>Copy recognized text to clipboard</source>
        <translation>Копировать текст в буфер обмена</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recognize &amp;All Pages</source>
        <translation>Распознать &amp;всё </translation>
    </message>
    <message>
        <source>Recognize All Pages</source>
        <translation>Распознать все страницы</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>&lt;&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide/Show Toolbar</source>
        <translation>Показать/убрать панель</translation>
    </message>
    <message>
        <source>Import from PDF...</source>
        <translation>Импорт из документа PDF...</translation>
    </message>
    <message>
        <source>Import pages from PDF documents</source>
        <translation>Импорт страниц из документа PDF</translation>
    </message>
    <message>
        <source>OCR Settings</source>
        <translation>Настройки программ распознавания</translation>
    </message>
    <message>
        <source>Set up the OCR parameters</source>
        <translation>Установить параметры программ распознавания</translation>
    </message>
    <message>
        <source>Paste Image</source>
        <translation>Вставить изображение</translation>
    </message>
    <message>
        <source>Paste image from clipboard</source>
        <translation>Вставить страницу из буфера обмена</translation>
    </message>
    <message>
        <source>Select Text Area</source>
        <translation>Автоматически выделить текстовую область</translation>
    </message>
    <message>
        <source>Deskew  Block</source>
        <translation>Выровнять блок</translation>
    </message>
    <message>
        <source>Deskew the current block</source>
        <translation>Выровнять выделенный блок</translation>
    </message>
    <message>
        <source>Deskew</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <source>Correct the page skew </source>
        <translation>Исправить наклон страницы</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Дополнительные настройки</translation>
    </message>
    <message>
        <source>The settings you should probably never change</source>
        <translation>Настройки, которые вам, скорее всего, менять не нужно</translation>
    </message>
    <message>
        <source>select multiple blocks</source>
        <translation>Разделить текст на блоки</translation>
    </message>
    <message>
        <source>Splits text into several blocks</source>
        <translation>Разбить текст на блоки</translation>
    </message>
    <message>
        <source>Toggle Large/Small Icons</source>
        <translation>Большие/маленькие иконки</translation>
    </message>
    <message>
        <source>toolBar_2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Recognition Language</source>
        <translation>Выбор языка распознавания</translation>
    </message>
    <message>
        <source>Prepare Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Project...</source>
        <translation>Сохранить проект...</translation>
    </message>
    <message>
        <source>Load Project...</source>
        <translation>Загрузить проект...</translation>
    </message>
    <message>
        <source>Prepare the page for recognition</source>
        <translation type="unfinished">Подготовить страницу для распознавания</translation>
    </message>
</context>
<context>
    <name>PopplerDialog</name>
    <message>
        <source>Import from PDF</source>
        <translation>Импорт из документа PDF</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Имя файла PDF</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Выбрать...</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Страницы</translation>
    </message>
    <message>
        <source>From</source>
        <translation>С</translation>
    </message>
    <message>
        <source>To</source>
        <translation>по</translation>
    </message>
    <message>
        <source>Entire Document</source>
        <translation>Весь документ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>JPEG Files (*.jpg)</source>
        <translation>Файлы JPEG (*.jpg)</translation>
    </message>
    <message>
        <source>PNG Files (*.png)</source>
        <translation>Файлы PNG (*.png)</translation>
    </message>
    <message>
        <source>Failed to save the image</source>
        <translation>Не удалось сохранить файл</translation>
    </message>
    <message>
        <source>Required spelling dictionary (%1) is not found.
Spell-checking is disabled.
Try to install an appropriate aspell dictionary.</source>
        <translation>Требуемый орфографический словарь (%1) не найден.
Проверка орфографии будет отключена.
Попробуйте установить соответствующий словарь aspell.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Select Project Directory</source>
        <translation>Выбор директории проекта</translation>
    </message>
    <message>
        <source>Bulgarian</source>
        <translation>Болгарский</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>Чешский</translation>
    </message>
    <message>
        <source>Danish</source>
        <translation>Датский</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation>Голландский</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Английский</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Французский</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Немецкий</translation>
    </message>
    <message>
        <source>Hungarian</source>
        <translation>Венгерский</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Итальянский</translation>
    </message>
    <message>
        <source>Latvian</source>
        <translation>Латышский</translation>
    </message>
    <message>
        <source>Lithuanian</source>
        <translation>Литовский</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Польский</translation>
    </message>
    <message>
        <source>Portuguese</source>
        <translation>Португальский</translation>
    </message>
    <message>
        <source>Romanian</source>
        <translation>Румынский</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>Russian-English</source>
        <translation>Русский-английский</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>Испанский</translation>
    </message>
    <message>
        <source>Serbian</source>
        <translation>Сербский</translation>
    </message>
    <message>
        <source>Slovenian</source>
        <translation>Словенский</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation>Шведский</translation>
    </message>
    <message>
        <source>Ukrainian</source>
        <translation>Украинский</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation>Финский</translation>
    </message>
    <message>
        <source>German Gothic</source>
        <translation>Немецкий готический</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Греческий</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Иврит</translation>
    </message>
    <message>
        <source>Norwegian</source>
        <translation>Норевежский</translation>
    </message>
    <message>
        <source>Slovak</source>
        <translation>Словацкий</translation>
    </message>
    <message>
        <source>Swedish Gothic</source>
        <translation>Шведский готический</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation>Турецкий</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Drop files here</source>
        <translation>Перетащите файлы сюда</translation>
    </message>
</context>
</TS>
